import { ContainerImage } from 'aws-cdk-lib/aws-ecs';
import { DockerImageCode } from 'aws-cdk-lib/aws-lambda';
import { Construct } from 'constructs';
/**
 * Properties for the `TokenInjectableDockerBuilder` construct.
 */
export interface TokenInjectableDockerBuilderProps {
    /**
     * The path to the directory containing the Dockerfile or source code.
     */
    readonly path: string;
    /**
     * Build arguments to pass to the Docker build process.
     * These are transformed into `--build-arg` flags.
     * @example
     * {
     *   TOKEN: 'my-secret-token',
     *   ENV: 'production'
     * }
     */
    readonly buildArgs?: {
        [key: string]: string;
    };
}
/**
 * A CDK construct to build and push Docker images to an ECR repository using CodeBuild and Lambda custom resources.
 *
 * @example
 * const dockerBuilder = new TokenInjectableDockerBuilder(this, 'DockerBuilder', {
 *   path: './docker',
 *   buildArgs: {
 *     TOKEN: 'my-secret-token',
 *     ENV: 'production'
 *   },
 * });
 *
 * const containerImage = dockerBuilder.getContainerImage();
 */
export declare class TokenInjectableDockerBuilder extends Construct {
    readonly containerImage: ContainerImage;
    readonly dockerImageCode: DockerImageCode;
    private readonly ecrRepository;
    /**
     * Creates a new `TokenInjectableDockerBuilder` instance.
     *
     * @param scope The parent construct/stack.
     * @param id The unique ID of the construct.
     * @param props Configuration properties for the construct.
     */
    constructor(scope: Construct, id: string, props: TokenInjectableDockerBuilderProps);
}
